@@ -1,5 +1,5 @@
 """
-API for Numpy usage.
+API for NumPy usage.
 """
 
 import functools
@@ -11,9 +11,9 @@ from targetran._check import (
     _check_shear_input,
     _check_translate_input,
     _check_crop_input,
-    _check_input_range
+    _check_input_range,
 )
-from targetran._functional import (
+from targetran._np_functional import (
     _np_convert,
     _np_range,
     _np_round_to_int,
@@ -21,7 +21,7 @@ from targetran._functional import (
     _np_boolean_mask,
     _np_logical_and,
     _np_pad_image,
-    _np_gather_image
+    _np_gather_image,
 )
 from targetran._transform import (
     _affine_transform,
@@ -38,7 +38,7 @@ from targetran._transform import (
     _get_flip_up_down_mats,
     _get_rotate_mats,
     _get_shear_mats,
-    _get_translate_mats
+    _get_translate_mats,
 )
 
 
@@ -212,7 +212,7 @@ class RandomTransform:
     def _rand_fn(self, shape: Tuple[int, ...] = ()) -> np.ndarray:
         return self._rng.random(shape)
 
-    def get_mats(
+    def _get_mats(
             self,
             image: np.ndarray,
             rand_fn: Callable[..., np.ndarray]
@@ -265,7 +265,7 @@ class CombineAffine(RandomTransform):
             rand_fn: Callable[..., np.ndarray]
     ) -> Tuple[np.ndarray, np.ndarray]:
         image_dest_tran_mats, bboxes_tran_mats, probs = tuple(zip(
-            *[(*t.get_mats(image, rand_fn), t.probability)
+            *[(*t._get_mats(image, rand_fn), t.probability)
               for i, t in enumerate(self._transforms)]
         ))
 
@@ -313,7 +313,7 @@ class RandomFlipLeftRight(RandomTransform):
             flip_left_right, probability, seed, "RandomFlipLeftRight", True
         )
 
-    def get_mats(
+    def _get_mats(
             self,
             image: np.ndarray,
             rand_fn: Callable[..., np.ndarray]
@@ -342,7 +342,7 @@ class RandomFlipUpDown(RandomTransform):
             flip_up_down, probability, seed, "RandomFlipUpDown", True
         )
 
-    def get_mats(
+    def _get_mats(
             self,
             image: np.ndarray,
             rand_fn: Callable[..., np.ndarray]
@@ -376,7 +376,7 @@ class RandomRotate(RandomTransform):
         return self.angle_deg_range[1] - self.angle_deg_range[0] \
                * rand_fn() + self.angle_deg_range[0]
 
-    def get_mats(
+    def _get_mats(
             self,
             image: np.ndarray,
             rand_fn: Callable[..., np.ndarray]
@@ -414,7 +414,7 @@ class RandomShear(RandomTransform):
         return self.angle_deg_range[1] - self.angle_deg_range[0] \
                * rand_fn() + self.angle_deg_range[0]
 
-    def get_mats(
+    def _get_mats(
             self,
             image: np.ndarray,
             rand_fn: Callable[..., np.ndarray]
@@ -473,7 +473,7 @@ class RandomTranslate(RandomTransform):
         )
         return translate_height, translate_width
 
-    def get_mats(
+    def _get_mats(
             self,
             image: np.ndarray,
             rand_fn: Callable[..., np.ndarray]
@@ -503,20 +503,22 @@ class RandomCrop(RandomTransform):
 
     def __init__(
             self,
-            crop_height_fraction_range: Tuple[float, float] = (0.7, 0.9),
-            crop_width_fraction_range: Tuple[float, float] = (0.7, 0.9),
+            cropped_height_fraction_range: Tuple[float, float] = (0.7, 0.9),
+            cropped_width_fraction_range: Tuple[float, float] = (0.7, 0.9),
             probability: float = 0.7,
             seed: Optional[int] = None
     ) -> None:
         _check_input_range(
-            crop_height_fraction_range, (0.0, 1.0), "crop_height_fraction_range"
+            cropped_height_fraction_range, (0.0, 1.0),
+            "cropped_height_fraction_range"
         )
         _check_input_range(
-            crop_width_fraction_range, (0.0, 1.0), "crop_width_fraction_range"
+            cropped_width_fraction_range, (0.0, 1.0),
+            "cropped_width_fraction_range"
         )
         super().__init__(crop, probability, seed, "RandomCrop", False)
-        self.crop_height_fraction_range = crop_height_fraction_range
-        self.crop_width_fraction_range = crop_width_fraction_range
+        self.cropped_height_fraction_range = cropped_height_fraction_range
+        self.cropped_width_fraction_range = cropped_width_fraction_range
 
     def __call__(
             self,
@@ -529,8 +531,8 @@ class RandomCrop(RandomTransform):
         offset_height, offset_width, cropped_height, cropped_width = \
             _np_get_crop_inputs(
                 np.shape(image)[0], np.shape(image)[1],
-                self.crop_height_fraction_range,
-                self.crop_width_fraction_range,
+                self.cropped_height_fraction_range,
+                self.cropped_width_fraction_range,
                 self._rand_fn
             )
 
