@@ -13,14 +13,14 @@ from targetran._check import (
     _check_shear_input,
     _check_translate_input,
     _check_crop_input,
-    _check_input_range
+    _check_input_range,
 )
-from targetran._functional import (
+from targetran._tf_functional import (
     _tf_convert,
     _tf_round_to_int,
     _tf_resize_image,
     _tf_pad_image,
-    _tf_gather_image
+    _tf_gather_image,
 )
 from targetran._transform import (
     _affine_transform,
@@ -37,7 +37,7 @@ from targetran._transform import (
     _get_flip_up_down_mats,
     _get_rotate_mats,
     _get_shear_mats,
-    _get_translate_mats
+    _get_translate_mats,
 )
 
 T = TypeVar("T", np.ndarray, tf.Tensor)
@@ -259,7 +259,7 @@ class TFRandomTransform:
     def _rand_fn(self, shape: Tuple[int, ...] = ()) -> tf.Tensor:
         return self._rng.uniform(shape=shape)
 
-    def get_mats(
+    def _get_mats(
             self,
             image: tf.Tensor,
             rand_fn: Callable[..., tf.Tensor]
@@ -312,7 +312,7 @@ class TFCombineAffine(TFRandomTransform):
             rand_fn: Callable[..., tf.Tensor]
     ) -> Tuple[tf.Tensor, tf.Tensor]:
         image_dest_tran_mats, bboxes_tran_mats, probs = tuple(zip(
-            *[(*t.get_mats(image, rand_fn), t.probability)
+            *[(*t._get_mats(image, rand_fn), t.probability)
               for i, t in enumerate(self._transforms)]
         ))
 
@@ -360,7 +360,7 @@ class TFRandomFlipLeftRight(TFRandomTransform):
             tf_flip_left_right, probability, seed, "TFRandomFlipLeftRight", True
         )
 
-    def get_mats(
+    def _get_mats(
             self,
             image: tf.Tensor,
             rand_fn: Callable[..., tf.Tensor]
@@ -389,7 +389,7 @@ class TFRandomFlipUpDown(TFRandomTransform):
             tf_flip_up_down, probability, seed, "TFRandomFlipUpDown", True
         )
 
-    def get_mats(
+    def _get_mats(
             self,
             image: tf.Tensor,
             rand_fn: Callable[..., tf.Tensor]
@@ -423,7 +423,7 @@ class TFRandomRotate(TFRandomTransform):
         return _tf_convert(self.angle_deg_range[1] - self.angle_deg_range[0]) \
                * rand_fn() + _tf_convert(self.angle_deg_range[0])
 
-    def get_mats(
+    def _get_mats(
             self,
             image: tf.Tensor,
             rand_fn: Callable[..., tf.Tensor]
@@ -461,7 +461,7 @@ class TFRandomShear(TFRandomTransform):
         return _tf_convert(self.angle_deg_range[1] - self.angle_deg_range[0]) \
                * rand_fn() + _tf_convert(self.angle_deg_range[0])
 
-    def get_mats(
+    def _get_mats(
             self,
             image: tf.Tensor,
             rand_fn: Callable[..., tf.Tensor]
@@ -520,7 +520,7 @@ class TFRandomTranslate(TFRandomTransform):
         translate_width = _tf_convert(tf.shape(image)[1]) * width_fraction
         return translate_height, translate_width
 
-    def get_mats(
+    def _get_mats(
             self,
             image: tf.Tensor,
             rand_fn: Callable[..., tf.Tensor]
@@ -550,20 +550,22 @@ class TFRandomCrop(TFRandomTransform):
 
     def __init__(
             self,
-            crop_height_fraction_range: Tuple[float, float] = (0.7, 0.9),
-            crop_width_fraction_range: Tuple[float, float] = (0.7, 0.9),
+            cropped_height_fraction_range: Tuple[float, float] = (0.7, 0.9),
+            cropped_width_fraction_range: Tuple[float, float] = (0.7, 0.9),
             probability: float = 0.7,
             seed: Optional[int] = None
     ) -> None:
         _check_input_range(
-            crop_height_fraction_range, (0.0, 1.0), "crop_height_fraction_range"
+            cropped_height_fraction_range, (0.0, 1.0),
+            "crop_height_fraction_range"
         )
         _check_input_range(
-            crop_width_fraction_range, (0.0, 1.0), "crop_width_fraction_range"
+            cropped_width_fraction_range, (0.0, 1.0),
+            "crop_width_fraction_range"
         )
         super().__init__(tf_crop, probability, seed, "TFRandomCrop", False)
-        self.crop_height_fraction_range = crop_height_fraction_range
-        self.crop_width_fraction_range = crop_width_fraction_range
+        self.cropped_height_fraction_range = cropped_height_fraction_range
+        self.cropped_width_fraction_range = cropped_width_fraction_range
 
     def __call__(
             self,
@@ -576,8 +578,8 @@ class TFRandomCrop(TFRandomTransform):
         offset_height, offset_width, cropped_height, cropped_width = \
             _tf_get_crop_inputs(
                 tf.shape(image)[0], tf.shape(image)[1],
-                self.crop_height_fraction_range,
-                self.crop_width_fraction_range,
+                self.cropped_height_fraction_range,
+                self.cropped_width_fraction_range,
                 self._rand_fn
             )
 
